@@ -45,7 +45,7 @@ class ThingMQTT:
         self.logger = thing.logger
 
         self.mqtt_client = None
-        self.connected = False 
+        self.connected = connect 
         
         if (connect):
             self.thread_mqtt = Thread(target=self.init)
