@@ -6,29 +6,21 @@
 from random import random
 import time
 
-from dotenv import load_dotenv
-import os
-import sys
-
-from dcd.entities.thing import Thing
+from dcd.bucket.thing import Thing
 
 def main():
-    # The thing ID
-    load_dotenv()
-    THING_ID = os.environ['THING_ID']
-
     # Instantiate a thing with its credential
-    my_thing = Thing(thing_id=THING_ID)
+    my_thing = Thing()
 
     # If you just registered your Thing on the DCD Hub,
     # it has only an id, a name and a type.
     print(my_thing.to_json())
 
     time.sleep(4)
-    my_thing.readMQTT()
+    my_thing.mqtt.read()
 
     time.sleep(4)
-    my_thing.find_or_create_propertyMQTT("Accelerometer from MQTT", "ACCELEROMETER")
+    my_thing.mqtt.find_or_create_property("Accelerometer from MQTT", "ACCELEROMETER")
     
 
 if __name__ == "__main__":
